
.. If you created a package, create one automodule per module in the package.

.. If your library file(s) are nested in a directory (e.g. /adafruit_foo/foo.py)
.. use this format as the module name: "adafruit_foo.foo"

.. automodule:: adafruit_blinka
   :members:

.. automodule:: adafruit_blinka.agnostic
  :members:

.. automodule:: adafruit_blinka.microcontroller
  :members:

.. automodule:: bitbangio
  :members:

.. automodule:: board
  :members:

.. automodule:: busio
  :members:

.. automodule:: digitalio
  :members:

.. automodule:: analogio
  :members:

.. automodule:: pulseio
  :members:

.. automodule:: neopixel_write
  :members:


